| Title: | Historical Data from John Snow's 1854 Cholera Outbreak Map |
|---|---|
| Description: | Provides historical datasets related to John Snow's 1854 cholera outbreak study in London. Includes data on cholera cases, water pump locations, and the street layout, enabling analysis and visualisation of the outbreak. |
| Authors: | Niamh Mimnagh [aut, cre] |
| Maintainer: | Niamh Mimnagh <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-05-12 06:54:07 UTC |
| Source: | https://github.com/cran/SnowData |
A dataset containing the locations of cholera cases in 1854 Soho, London
data(cholera_cases)data(cholera_cases)
A data frame with 5 rows and 317 columns:
Observation-level identifier
Count of cholera deaths
Variable used for aligning barcharts along streets, for use when re-creating the barchart approach of John Snow
X-coordinate in Ordnance Survey National Grid (OSGB36) projection
Y-coordinate in Ordnance Survey National Grid (OSGB36) projection
John Snow's 1854 cholera outbreak map, georeferenced and processed by Niamh Mimnagh. Original map and data can be found in the public domain at: Snow, J. (1855). On the Mode of Communication of Cholera. (Online) Available: https://commons.wikimedia.org/wiki/File:Snow-cholera-map-1.jpg
This function loads the included .tif file using terra.
load_map()load_map()
A SpatRaster object.
tif <- load_map()tif <- load_map()
A dataset containing the locations of water pumps in 1854 Soho, London
data(pump_locations)data(pump_locations)
A data frame with 3 rows and 13 columns:
Observation-level identifier
X-coordinate in Ordnance Survey National Grid (OSGB36) projection
Y-coordinate in Ordnance Survey National Grid (OSGB36) projection
John Snow's 1854 cholera outbreak map, georeferenced and processed by Niamh Mimnagh. Original map and data can be found in the public domain at: Snow, J. (1855). On the Mode of Communication of Cholera. (Online) Available: https://commons.wikimedia.org/wiki/File:Snow-cholera-map-1.jpg
A dataset containing the start-points and end-points of streets in 1854 Soho, London
data(streets)data(streets)
A data frame with 5 rows and 317 columns:
Observation-level identifier
Length of street section in metres
Street start-point identifier
Street end-point identifier
X-coordinate in Ordnance Survey National Grid (OSGB36) projection of the start-point
Y-coordinate in Ordnance Survey National Grid (OSGB36) projection of the start-point
X-coordinate in Ordnance Survey National Grid (OSGB36) projection of the end-point
Y-coordinate in Ordnance Survey National Grid (OSGB36) projection of the end-point
John Snow's 1854 cholera outbreak map, georeferenced and processed by Niamh Mimnagh. Original map and data can be found in the public domain at: Snow, J. (1855). On the Mode of Communication of Cholera. (Online) Available: https://commons.wikimedia.org/wiki/File:Snow-cholera-map-1.jpg